@@ -20,6 +20,7 @@
 
 #include <config.h>
 #include <libedata-cal/e-cal-backend-cache.h>
+#include <libedata-cal/e-cal-backend-file-store.h>
 #include <libedata-cal/e-cal-backend-util.h>
 #include <libedata-cal/e-cal-backend-sexp.h>
 #include <glib/gi18n-lib.h>
@@ -37,18 +38,18 @@ static gboolean reload_cb (ECalBackendWeather *cbw);
 static gboolean begin_retrieval_cb (ECalBackendWeather *cbw);
 static ECalComponent* create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_forecast);
 static ECalBackendSyncStatus
-e_cal_backend_weather_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj);
+e_cal_backend_weather_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj);
 
 /* Private part of the ECalBackendWeather structure */
 struct _ECalBackendWeatherPrivate {
 	/* URI to get remote weather data from */
-	char *uri;
+	gchar *uri;
 
 	/* Local/remote mode */
 	CalMode mode;
 
 	/* The file cache */
-	ECalBackendCache *cache;
+	ECalBackendStore *store;
 
 	/* The calendar's default timezone, used for resolving DATE and
 	   floating DATE-TIME values. */
@@ -119,7 +120,7 @@ maybe_start_reload_timeout (ECalBackendWeather *cbw)
 
 	if (priv->source_changed_id == 0)
 		priv->source_changed_id = g_signal_connect (G_OBJECT (source),
-		                                            "changed",
+							    "changed",
 							    G_CALLBACK (source_changed),
 							    cbw);
 
@@ -130,7 +131,7 @@ maybe_start_reload_timeout (ECalBackendWeather *cbw)
 	 * serious bandwidth, they would appreciate it if we didn't hammer their servers
 	 */
 	priv->reload_timeout_id = g_timeout_add ((refresh_str ? atoi (refresh_str) : 240) * 60000,
-	    					 (GSourceFunc) reload_cb, cbw);
+						 (GSourceFunc) reload_cb, cbw);
 
 }
 
@@ -140,8 +141,8 @@ finished_retrieval_cb (WeatherInfo *info, ECalBackendWeather *cbw)
 	ECalBackendWeatherPrivate *priv;
 	ECalComponent *comp;
 	icalcomponent *icomp;
-	GList *l;
-	char *obj;
+	GSList *l;
+	gchar *obj;
 
 	priv = cbw->priv;
 
@@ -151,15 +152,15 @@ finished_retrieval_cb (WeatherInfo *info, ECalBackendWeather *cbw)
 	}
 
 	/* update cache */
-	l = e_cal_backend_cache_get_components (priv->cache);
-	for (; l != NULL; l = g_list_next (l)) {
+	l = e_cal_backend_store_get_components (priv->store);
+	for (; l != NULL; l = g_slist_next (l)) {
 		ECalComponentId *id;
-		char *obj;
+		gchar *obj;
 
 		icomp = e_cal_component_get_icalcomponent (E_CAL_COMPONENT (l->data));
 		id = e_cal_component_get_id (E_CAL_COMPONENT (l->data));
 
-		obj = icalcomponent_as_ical_string (icomp);
+		obj = icalcomponent_as_ical_string_r (icomp);
 		e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbw),
 			id,
 			obj,
@@ -169,18 +170,19 @@ finished_retrieval_cb (WeatherInfo *info, ECalBackendWeather *cbw)
 		g_free (obj);
 		g_object_unref (G_OBJECT (l->data));
 	}
-	g_list_free (l);
-	e_file_cache_clean (E_FILE_CACHE (priv->cache));
+	g_slist_free (l);
+	e_cal_backend_store_clean (priv->store);
 
 	comp = create_weather (cbw, info, FALSE);
 	if (comp) {
 		GSList *forecasts;
 
-		e_cal_backend_cache_put_component (priv->cache, comp);
+		e_cal_backend_store_put_component (priv->store, comp);
 		icomp = e_cal_component_get_icalcomponent (comp);
-		obj = icalcomponent_as_ical_string (icomp);
+		obj = icalcomponent_as_ical_string_r (icomp);
 		e_cal_backend_notify_object_created (E_CAL_BACKEND (cbw), obj);
 		g_free (obj);
+		g_object_unref (comp);
 
 		forecasts = weather_info_get_forecast_list (info);
 		if (forecasts) {
@@ -193,11 +195,12 @@ finished_retrieval_cb (WeatherInfo *info, ECalBackendWeather *cbw)
 				if (nfo) {
 					comp = create_weather (cbw, nfo, TRUE);
 					if (comp) {
-						e_cal_backend_cache_put_component (priv->cache, comp);
+						e_cal_backend_store_put_component (priv->store, comp);
 						icomp = e_cal_component_get_icalcomponent (comp);
-						obj = icalcomponent_as_ical_string (icomp);
+						obj = icalcomponent_as_ical_string_r (icomp);
 						e_cal_backend_notify_object_created (E_CAL_BACKEND (cbw), obj);
 						g_free (obj);
+						g_object_unref (comp);
 					}
 				}
 			}
@@ -236,27 +239,27 @@ begin_retrieval_cb (ECalBackendWeather *cbw)
 	return FALSE;
 }
 
-static const char*
+static const gchar *
 getCategory (WeatherInfo *report)
 {
 	struct {
-		const char *description;
-		const char *icon_name;
+		const gchar *description;
+		const gchar *icon_name;
 	} categories[] = {
-		{ N_("Weather: Fog"), 		"weather-fog" },
-		{ N_("Weather: Cloudy"), 	"weather-few-clouds" },
+		{ N_("Weather: Fog"),		"weather-fog" },
+		{ N_("Weather: Cloudy"),	"weather-few-clouds" },
 		{ N_("Weather: Cloudy Night"),	"weather-few-clouds-night" },
 		{ N_("Weather: Overcast"),	"weather-overcast" },
-		{ N_("Weather: Showers"), 	"weather-showers" },
-		{ N_("Weather: Snow"), 		"weather-snow" },
-		{ N_("Weather: Sunny"), 	"weather-clear" },
-		{ N_("Weather: Clear Night"), 	"weather-clear-night" },
+		{ N_("Weather: Showers"),	"weather-showers" },
+		{ N_("Weather: Snow"),		"weather-snow" },
+		{ N_("Weather: Sunny"),	"weather-clear" },
+		{ N_("Weather: Clear Night"),	"weather-clear-night" },
 		{ N_("Weather: Thunderstorms"), "weather-storm" },
 		{ NULL,				NULL }
 	};
 
-	int i;
-	const char *icon_name = weather_info_get_icon_name (report);
+	gint i;
+	const gchar *icon_name = weather_info_get_icon_name (report);
 
 	if (!icon_name)
 		return NULL;
@@ -278,12 +281,12 @@ create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_foreca
 	icalcomponent             *ical_comp;
 	struct icaltimetype        itt;
 	ECalComponentDateTime      dt;
-	char                	  *uid;
+	gchar			  *uid;
 	GSList                    *text_list = NULL;
 	ECalComponentText         *description;
 	ESource                   *source;
 	gboolean                   metric;
-	const char                *tmp;
+	const gchar                *tmp;
 	time_t			   update_time;
 	icaltimezone		  *update_zone = NULL;
 	const WeatherLocation     *location;
@@ -353,7 +356,7 @@ create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_foreca
 	if (is_forecast) {
 		gdouble tmin = 0.0, tmax = 0.0;
 
-		if (weather_info_get_value_temp_min (report, TEMP_UNIT_DEFAULT, &tmin) && 
+		if (weather_info_get_value_temp_min (report, TEMP_UNIT_DEFAULT, &tmin) &&
 		    weather_info_get_value_temp_max (report, TEMP_UNIT_DEFAULT, &tmax) &&
 		    tmin != tmax) {
 			/* because weather_info_get_temp* uses one internal buffer, thus finally
@@ -376,7 +379,7 @@ create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_foreca
 		GString *str = g_string_new (priv->city);
 
 		g_string_append (str, " : ");
-		if (weather_info_get_value_temp_min (report, TEMP_UNIT_DEFAULT, &tmin) && 
+		if (weather_info_get_value_temp_min (report, TEMP_UNIT_DEFAULT, &tmin) &&
 		    weather_info_get_value_temp_max (report, TEMP_UNIT_DEFAULT, &tmax) &&
 		    tmin != tmax) {
 			g_string_append (str, weather_info_get_temp_min (report));
@@ -390,7 +393,7 @@ create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_foreca
 	}
 	comp_summary.altrep = NULL;
 	e_cal_component_set_summary (cal_comp, &comp_summary);
-	g_free ((char *)comp_summary.value);
+	g_free ((gchar *)comp_summary.value);
 
 	tmp = weather_info_get_forecast (report);
 	comp_summary.value = weather_info_get_weather_summary (report);
@@ -400,7 +403,7 @@ create_weather (ECalBackendWeather *cbw, WeatherInfo *report, gboolean is_foreca
 	description->altrep = "";
 	text_list = g_slist_append (text_list, description);
 	e_cal_component_set_description_list (cal_comp, text_list);
-	g_free ((char *)comp_summary.value);
+	g_free ((gchar *)comp_summary.value);
 
 	/* Set category and visibility */
 	e_cal_component_set_categories (cal_comp, getCategory (report));
@@ -423,7 +426,7 @@ e_cal_backend_weather_is_read_only (ECalBackendSync *backend, EDataCal *cal, gbo
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_cal_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_weather_get_cal_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	/* Weather has no particular email addresses associated with it */
 	*address = NULL;
@@ -432,7 +435,7 @@ e_cal_backend_weather_get_cal_address (ECalBackendSync *backend, EDataCal *cal,
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, char **address)
+e_cal_backend_weather_get_alarm_email_address (ECalBackendSync *backend, EDataCal *cal, gchar **address)
 {
 	/* Weather has no particular email addresses associated with it */
 	*address = NULL;
@@ -441,7 +444,7 @@ e_cal_backend_weather_get_alarm_email_address (ECalBackendSync *backend, EDataCa
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, char **attribute)
+e_cal_backend_weather_get_ldap_attribute (ECalBackendSync *backend, EDataCal *cal, gchar **attribute)
 {
 	*attribute = NULL;
 
@@ -449,7 +452,7 @@ e_cal_backend_weather_get_ldap_attribute (ECalBackendSync *backend, EDataCal *ca
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
+e_cal_backend_weather_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, gchar **capabilities)
 {
 	*capabilities = g_strdup (CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT ","
 				  CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS  ","
@@ -463,11 +466,11 @@ e_cal_backend_weather_get_static_capabilities (ECalBackendSync *backend, EDataCa
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists, const char *username, const char *password)
+e_cal_backend_weather_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_if_exists, const gchar *username, const gchar *password)
 {
 	ECalBackendWeather *cbw;
 	ECalBackendWeatherPrivate *priv;
-	const char *uri;
+	const gchar *uri;
 
 	cbw = E_CAL_BACKEND_WEATHER (backend);
 	priv = cbw->priv;
@@ -477,13 +480,15 @@ e_cal_backend_weather_open (ECalBackendSync *backend, EDataCal *cal, gboolean on
 		g_free (priv->city);
 	priv->city = g_strdup (strrchr (uri, '/') + 1);
 
-	if (!priv->cache) {
-		priv->cache = e_cal_backend_cache_new (uri, E_CAL_SOURCE_TYPE_EVENT);
+	if (!priv->store) {
+		e_cal_backend_cache_remove (uri, E_CAL_SOURCE_TYPE_EVENT);
+		priv->store = (ECalBackendStore *) e_cal_backend_file_store_new (uri, E_CAL_SOURCE_TYPE_EVENT);
 
-		if (!priv->cache) {
+		if (!priv->store) {
 			e_cal_backend_notify_error (E_CAL_BACKEND (cbw), _("Could not create cache file"));
 			return GNOME_Evolution_Calendar_OtherError;
 		}
+		e_cal_backend_store_load (priv->store);
 
 		if (priv->default_zone) {
 			icalcomponent *icalcomp = icaltimezone_get_component (priv->default_zone);
@@ -513,45 +518,45 @@ e_cal_backend_weather_remove (ECalBackendSync *backend, EDataCal *cal)
 	cbw = E_CAL_BACKEND_WEATHER (backend);
 	priv = cbw->priv;
 
-	if (!priv->cache) {
+	if (!priv->store) {
 		/* lie here a bit, but otherwise the calendar will not be removed, even it should */
 		g_print (G_STRLOC ": Doesn't have a cache?!?");
 		return GNOME_Evolution_Calendar_Success;
 	}
 
-	e_file_cache_remove (E_FILE_CACHE (priv->cache));
+	e_cal_backend_store_remove (priv->store);
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *auid)
+e_cal_backend_weather_discard_alarm (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *auid)
 {
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_receive_objects (ECalBackendSync *backend, EDataCal *cal, const char *calobj)
+e_cal_backend_weather_receive_objects (ECalBackendSync *backend, EDataCal *cal, const gchar *calobj)
 {
 	return GNOME_Evolution_Calendar_PermissionDenied;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_default_object (ECalBackendSync *backend, EDataCal *cal, char **object)
+e_cal_backend_weather_get_default_object (ECalBackendSync *backend, EDataCal *cal, gchar **object)
 {
 	return GNOME_Evolution_Calendar_UnsupportedMethod;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_object (ECalBackendSync *backend, EDataCal *cal, const char *uid, const char *rid, char **object)
+e_cal_backend_weather_get_object (ECalBackendSync *backend, EDataCal *cal, const gchar *uid, const gchar *rid, gchar **object)
 {
 	ECalBackendWeather *cbw = E_CAL_BACKEND_WEATHER (backend);
 	ECalBackendWeatherPrivate *priv = cbw->priv;
 	ECalComponent *comp;
 
 	g_return_val_if_fail (uid != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
-	g_return_val_if_fail (priv->cache != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
+	g_return_val_if_fail (priv->store != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
 
-	comp = e_cal_backend_cache_get_component (priv->cache, uid, rid);
+	comp = e_cal_backend_store_get_component (priv->store, uid, rid);
 	g_return_val_if_fail (comp != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
 
 	*object = e_cal_component_get_as_string (comp);
@@ -561,32 +566,32 @@ e_cal_backend_weather_get_object (ECalBackendSync *backend, EDataCal *cal, const
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_object_list (ECalBackendSync *backend, EDataCal *cal, const char *sexp_string, GList **objects)
+e_cal_backend_weather_get_object_list (ECalBackendSync *backend, EDataCal *cal, const gchar *sexp_string, GList **objects)
 {
 	ECalBackendWeather *cbw = E_CAL_BACKEND_WEATHER (backend);
 	ECalBackendWeatherPrivate *priv = cbw->priv;
 	ECalBackendSExp *sexp = e_cal_backend_sexp_new (sexp_string);
-	GList *components, *l;
+	GSList *components, *l;
 
 	if (!sexp)
 		return GNOME_Evolution_Calendar_InvalidQuery;
 
 	*objects = NULL;
-	components = e_cal_backend_cache_get_components (priv->cache);
-	for (l = components; l != NULL; l = g_list_next (l)) {
+	components = e_cal_backend_store_get_components (priv->store);
+	for (l = components; l != NULL; l = g_slist_next (l)) {
 		if (e_cal_backend_sexp_match_comp (sexp, E_CAL_COMPONENT (l->data), E_CAL_BACKEND (backend)))
 			*objects = g_list_append (*objects, e_cal_component_get_as_string (l->data));
 	}
 
-	g_list_foreach (components, (GFunc) g_object_unref, NULL);
-	g_list_free (components);
+	g_slist_foreach (components, (GFunc) g_object_unref, NULL);
+	g_slist_free (components);
 	g_object_unref (sexp);
 
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzid, char **object)
+e_cal_backend_weather_get_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzid, gchar **object)
 {
 	ECalBackendWeather *cbw;
 	ECalBackendWeatherPrivate *priv;
@@ -606,19 +611,19 @@ e_cal_backend_weather_get_timezone (ECalBackendSync *backend, EDataCal *cal, con
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
 
-	*object = icalcomponent_as_ical_string (icalcomp);
+	*object = icalcomponent_as_ical_string_r (icalcomp);
 
 	return GNOME_Evolution_Calendar_Success;
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_add_timezone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_weather_add_timezone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	ECalBackendWeather *cbw;
 	ECalBackendWeatherPrivate *priv;
 	icalcomponent *tz_comp;
 	icaltimezone *zone;
-	char *tzid;
+	const gchar *tzid;
 
 	cbw = (ECalBackendWeather*) backend;
 
@@ -647,7 +652,7 @@ e_cal_backend_weather_add_timezone (ECalBackendSync *backend, EDataCal *cal, con
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const char *tzobj)
+e_cal_backend_weather_set_default_zone (ECalBackendSync *backend, EDataCal *cal, const gchar *tzobj)
 {
 	icalcomponent *tz_comp;
 	ECalBackendWeather *cbw;
@@ -683,12 +688,12 @@ e_cal_backend_weather_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GL
 	/* Weather doesn't count as busy time */
 	icalcomponent *vfb = icalcomponent_new_vfreebusy ();
 	icaltimezone *utc_zone = icaltimezone_get_utc_timezone ();
-	char *calobj;
+	gchar *calobj;
 
 	icalcomponent_set_dtstart (vfb, icaltime_from_timet_with_zone (start, FALSE, utc_zone));
 	icalcomponent_set_dtend (vfb, icaltime_from_timet_with_zone (end, FALSE, utc_zone));
 
-	calobj = icalcomponent_as_ical_string (vfb);
+	calobj = icalcomponent_as_ical_string_r (vfb);
 	*freebusy = g_list_append (NULL, calobj);
 	icalcomponent_free (vfb);
 
@@ -696,7 +701,7 @@ e_cal_backend_weather_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GL
 }
 
 static ECalBackendSyncStatus
-e_cal_backend_weather_get_changes (ECalBackendSync *backend, EDataCal *cal, const char *change_id, GList **adds, GList **modifies, GList **deletes)
+e_cal_backend_weather_get_changes (ECalBackendSync *backend, EDataCal *cal, const gchar *change_id, GList **adds, GList **modifies, GList **deletes)
 {
 	return GNOME_Evolution_Calendar_Success;
 }
@@ -710,7 +715,7 @@ e_cal_backend_weather_is_loaded (ECalBackend *backend)
 	cbw = E_CAL_BACKEND_WEATHER (backend);
 	priv = cbw->priv;
 
-	if (!priv->cache)
+	if (!priv->store)
 		return FALSE;
 
 	return TRUE;
@@ -721,12 +726,13 @@ static void e_cal_backend_weather_start_query (ECalBackend *backend, EDataCalVie
 	ECalBackendWeather *cbw;
 	ECalBackendWeatherPrivate *priv;
 	ECalBackendSExp *sexp;
-	GList *components, *l, *objects;
+	GSList *components, *l;
+	GList *objects;
 
 	cbw = E_CAL_BACKEND_WEATHER (backend);
 	priv = cbw->priv;
 
-	if (!priv->cache) {
+	if (!priv->store) {
 		e_data_cal_view_notify_done (query, GNOME_Evolution_Calendar_NoSuchCal);
 		return;
 	}
@@ -738,8 +744,8 @@ static void e_cal_backend_weather_start_query (ECalBackend *backend, EDataCalVie
 	}
 
 	objects = NULL;
-	components = e_cal_backend_cache_get_components (priv->cache);
-	for (l = components; l != NULL; l = g_list_next (l)) {
+	components = e_cal_backend_store_get_components (priv->store);
+	for (l = components; l != NULL; l = g_slist_next (l)) {
 		if (e_cal_backend_sexp_match_comp (sexp, E_CAL_COMPONENT (l->data), backend))
 			objects = g_list_append (objects, e_cal_component_get_as_string (l->data));
 	}
@@ -747,8 +753,8 @@ static void e_cal_backend_weather_start_query (ECalBackend *backend, EDataCalVie
 	if (objects)
 		e_data_cal_view_notify_objects_added (query, (const GList *) objects);
 
-	g_list_foreach (components, (GFunc) g_object_unref, NULL);
-	g_list_free (components);
+	g_slist_foreach (components, (GFunc) g_object_unref, NULL);
+	g_slist_free (components);
 	g_list_foreach (objects, (GFunc) g_free, NULL);
 	g_list_free (objects);
 	g_object_unref (sexp);
@@ -823,7 +829,7 @@ e_cal_backend_weather_internal_get_default_timezone (ECalBackend *backend)
 }
 
 static icaltimezone *
-e_cal_backend_weather_internal_get_timezone (ECalBackend *backend, const char *tzid)
+e_cal_backend_weather_internal_get_timezone (ECalBackend *backend, const gchar *tzid)
 {
 	icaltimezone *zone;
 	if (!strcmp (tzid, "UTC"))
@@ -866,9 +872,9 @@ e_cal_backend_weather_finalize (GObject *object)
 		priv->begin_retrival_id = 0;
 	}
 
-	if (priv->cache) {
-		g_object_unref (priv->cache);
-		priv->cache = NULL;
+	if (priv->store) {
+		g_object_unref (priv->store);
+		priv->store = NULL;
 	}
 
 	g_hash_table_destroy (priv->zones);
@@ -905,7 +911,7 @@ e_cal_backend_weather_init (ECalBackendWeather *cbw, ECalBackendWeatherClass *cl
 	priv->begin_retrival_id = 0;
 	priv->opened = FALSE;
 	priv->source = NULL;
-	priv->cache = NULL;
+	priv->store = NULL;
 	priv->city = NULL;
 
 	priv->zones = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, free_zone);
@@ -955,7 +961,6 @@ e_cal_backend_weather_class_init (ECalBackendWeatherClass *class)
 	backend_class->internal_get_timezone = e_cal_backend_weather_internal_get_timezone;
 }
 
-
 /**
  * e_cal_backend_weather_get_type:
  * @void:
