@@ -45,25 +45,24 @@
 #define EXTRACT_FIRST_DIGIT(val) val=strtoul (part, &part, 10);
 #define EXTRACT_DIGIT(val) if (*part) part++; val=strtoul (part, &part, 10);
 
-static int summary_header_load (CamelFolderSummary *, FILE *);
-static int summary_header_save (CamelFolderSummary *, FILE *);
+static gint summary_header_load (CamelFolderSummary *, FILE *);
+static gint summary_header_save (CamelFolderSummary *, FILE *);
 
 static CamelMessageInfo *message_info_load (CamelFolderSummary *s, FILE *in);
-static int message_info_save (CamelFolderSummary *s, FILE *out,
+static gint message_info_save (CamelFolderSummary *s, FILE *out,
 			      CamelMessageInfo *info);
-static gboolean info_set_user_flag (CamelMessageInfo *info, const char *id, gboolean state);
+static gboolean info_set_user_flag (CamelMessageInfo *info, const gchar *id, gboolean state);
 static CamelMessageContentInfo *content_info_load (CamelFolderSummary *s, FILE *in);
-static int content_info_save (CamelFolderSummary *s, FILE *out,
+static gint content_info_save (CamelFolderSummary *s, FILE *out,
 			      CamelMessageContentInfo *info);
 
-static int summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir);
+static gint summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir);
 static CamelFIRecord * summary_header_to_db (CamelFolderSummary *s, CamelException *ex);
 static CamelMIRecord * message_info_to_db (CamelFolderSummary *s, CamelMessageInfo *info);
 static CamelMessageInfo * message_info_from_db (CamelFolderSummary *s, CamelMIRecord *mir);
-static int content_info_to_db (CamelFolderSummary *s, CamelMessageContentInfo *info, CamelMIRecord *mir);
+static gint content_info_to_db (CamelFolderSummary *s, CamelMessageContentInfo *info, CamelMIRecord *mir);
 static CamelMessageContentInfo * content_info_from_db (CamelFolderSummary *s, CamelMIRecord *mir);
 
-
 static void camel_imap_summary_class_init (CamelImapSummaryClass *klass);
 static void camel_imap_summary_init       (CamelImapSummary *obj);
 
@@ -118,7 +117,7 @@ camel_imap_summary_class_init (CamelImapSummaryClass *klass)
 	cfs_class->message_info_save = message_info_save;
 	cfs_class->content_info_load = content_info_load;
 	cfs_class->content_info_save = content_info_save;
-	
+
 	cfs_class->summary_header_to_db = summary_header_to_db;
 	cfs_class->summary_header_from_db = summary_header_from_db;
 	cfs_class->message_info_to_db = message_info_to_db;
@@ -139,12 +138,12 @@ camel_imap_summary_init (CamelImapSummary *obj)
 	s->content_info_size = sizeof(CamelImapMessageContentInfo);
 }
 
-static int 
-sort_uid_cmp (void *enc, int len1, void * data1, int len2, void *data2)
+static gint
+sort_uid_cmp (gpointer enc, gint len1, gpointer  data1, gint len2, gpointer data2)
 {
-	static char *sa1=NULL, *sa2=NULL;
-	static int l1=0, l2=0;
-	int a1, a2;
+	static gchar *sa1=NULL, *sa2=NULL;
+	static gint l1=0, l2=0;
+	gint a1, a2;
 
 	if (l1 < len1+1) {
 		sa1 = g_realloc (sa1, len1+1);
@@ -155,7 +154,7 @@ sort_uid_cmp (void *enc, int len1, void * data1, int len2, void *data2)
 		l2 = len2+1;
 	}
 	strncpy (sa1, data1, len1);sa1[len1] = 0;
-	strncpy (sa2, data2, len2);sa2[len2] = 0;	
+	strncpy (sa2, data2, len2);sa2[len2] = 0;
 
 	a1 = strtoul (sa1, NULL, 10);
 	a2 = strtoul (sa2, NULL, 10);
@@ -163,11 +162,11 @@ sort_uid_cmp (void *enc, int len1, void * data1, int len2, void *data2)
 	return (a1 < a1) ? -1 : (a1 > a2) ? 1 : 0;
 }
 
-static int
-uid_compare (const void *va, const void *vb)
+static gint
+uid_compare (gconstpointer va, gconstpointer vb)
 {
-	const char **sa = (const char **)va, **sb = (const char **)vb;
-	unsigned long a, b;
+	const gchar **sa = (const gchar **)va, **sb = (const gchar **)vb;
+	gulong a, b;
 
 	a = strtoul (*sa, NULL, 10);
 	b = strtoul (*sb, NULL, 10);
@@ -190,7 +189,7 @@ uid_compare (const void *va, const void *vb)
  * Return value: A new CamelImapSummary object.
  **/
 CamelFolderSummary *
-camel_imap_summary_new (struct _CamelFolder *folder, const char *filename)
+camel_imap_summary_new (struct _CamelFolder *folder, const gchar *filename)
 {
 	CamelFolderSummary *summary = CAMEL_FOLDER_SUMMARY (camel_object_new (camel_imap_summary_get_type ()));
 	CamelException ex;
@@ -216,16 +215,16 @@ camel_imap_summary_new (struct _CamelFolder *folder, const char *filename)
 		camel_exception_clear (&ex);
 	}
 
-	g_ptr_array_sort (summary->uids, (GCompareFunc) uid_compare); 
+	g_ptr_array_sort (summary->uids, (GCompareFunc) uid_compare);
 
 	return summary;
 }
 
-static int
+static gint
 summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir)
 {
 	CamelImapSummary *ims = CAMEL_IMAP_SUMMARY (s);
-	char *part;
+	gchar *part;
 
 	if (camel_imap_summary_parent->summary_header_from_db (s, mir) == -1)
 		return -1;
@@ -235,11 +234,11 @@ summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir)
 	if (part) {
 		EXTRACT_FIRST_DIGIT (ims->version)
 	}
-	
+
 	if (part) {
 		EXTRACT_DIGIT (ims->validity)
 	}
-	
+
 	if (ims->version > CAMEL_IMAP_SUMMARY_VERSION) {
 		g_warning("Unkown summary version\n");
 		errno = EINVAL;
@@ -249,11 +248,11 @@ summary_header_from_db (CamelFolderSummary *s, CamelFIRecord *mir)
 	return 0;
 }
 
-static int
+static gint
 summary_header_load (CamelFolderSummary *s, FILE *in)
 {
 	CamelImapSummary *ims = CAMEL_IMAP_SUMMARY (s);
-	
+
 	if (camel_imap_summary_parent->summary_header_load (s, in) == -1)
 		return -1;
 
@@ -262,20 +261,20 @@ summary_header_load (CamelFolderSummary *s, FILE *in)
 		return camel_file_util_decode_uint32(in, &ims->validity);
 
 	/* Version 1 */
-	if (camel_file_util_decode_fixed_int32(in, &ims->version) == -1)
+	if (camel_file_util_decode_fixed_int32(in, (gint32 *) &ims->version) == -1)
 		return -1;
-	
+
 	if (ims->version == 2) {
 		/* Version 2: for compat with version 2 of the imap4 summary files */
-		int have_mlist;
-		
+		gint have_mlist;
+
 		if (camel_file_util_decode_fixed_int32 (in, &have_mlist) == -1)
 			return -1;
 	}
-	
-	if (camel_file_util_decode_fixed_int32(in, &ims->validity) == -1)
+
+	if (camel_file_util_decode_fixed_int32(in, (gint32 *) &ims->validity) == -1)
 		return -1;
-	
+
 	if (ims->version > CAMEL_IMAP_SUMMARY_VERSION) {
 		g_warning("Unkown summary version\n");
 		errno = EINVAL;
@@ -290,7 +289,7 @@ summary_header_to_db (CamelFolderSummary *s, CamelException *ex)
 {
 	CamelImapSummary *ims = CAMEL_IMAP_SUMMARY(s);
 	struct _CamelFIRecord *fir;
-	
+
 	fir = camel_imap_summary_parent->summary_header_to_db (s, ex);
 	if (!fir)
 		return NULL;
@@ -299,7 +298,7 @@ summary_header_to_db (CamelFolderSummary *s, CamelException *ex)
 	return fir;
 }
 
-static int
+static gint
 summary_header_save (CamelFolderSummary *s, FILE *out)
 {
 	CamelImapSummary *ims = CAMEL_IMAP_SUMMARY(s);
@@ -320,7 +319,7 @@ message_info_from_db (CamelFolderSummary *s, CamelMIRecord *mir)
 
 	info = camel_imap_summary_parent->message_info_from_db (s, mir);
 	if (info) {
-		char *part = g_strdup (mir->bdata), *tmp;
+		gchar *part = g_strdup (mir->bdata), *tmp;
 		tmp = part;
 		iinfo = (CamelImapMessageInfo *)info;
 		EXTRACT_FIRST_DIGIT (iinfo->server_flags)
@@ -357,13 +356,13 @@ message_info_to_db (CamelFolderSummary *s, CamelMessageInfo *info)
 	struct _CamelMIRecord *mir;
 
 	mir = camel_imap_summary_parent->message_info_to_db (s, info);
-	if (mir) 
+	if (mir)
 		mir->bdata = g_strdup_printf ("%u", iinfo->server_flags);
 
 	return mir;
 }
 
-static int
+static gint
 message_info_save (CamelFolderSummary *s, FILE *out, CamelMessageInfo *info)
 {
 	CamelImapMessageInfo *iinfo = (CamelImapMessageInfo *)info;
@@ -375,7 +374,7 @@ message_info_save (CamelFolderSummary *s, FILE *out, CamelMessageInfo *info)
 }
 
 static gboolean
-info_set_user_flag (CamelMessageInfo *info, const char *id, gboolean state)
+info_set_user_flag (CamelMessageInfo *info, const gchar *id, gboolean state)
 {
 	gboolean res;
 
@@ -391,13 +390,13 @@ info_set_user_flag (CamelMessageInfo *info, const char *id, gboolean state)
 static CamelMessageContentInfo *
 content_info_from_db (CamelFolderSummary *s, CamelMIRecord *mir)
 {
-	char *part = mir->cinfo;
+	gchar *part = mir->cinfo;
 	guint32 type=0;
-	
+
 	if (part) {
 		if (*part == ' ')
 			part++;
-		if (part){
+		if (part) {
 			EXTRACT_FIRST_DIGIT (type);
 		}
 	}
@@ -417,10 +416,10 @@ content_info_load (CamelFolderSummary *s, FILE *in)
 		return camel_folder_summary_content_info_new (s);
 }
 
-static int
+static gint
 content_info_to_db (CamelFolderSummary *s, CamelMessageContentInfo *info, CamelMIRecord *mir)
 {
-	char *oldr;
+	gchar *oldr;
 	if (info->type) {
 		oldr = mir->cinfo;
 		mir->cinfo = oldr ? g_strdup_printf("%s 1", oldr) : g_strdup ("1");
@@ -434,7 +433,7 @@ content_info_to_db (CamelFolderSummary *s, CamelMessageContentInfo *info, CamelM
 	}
 }
 
-static int
+static gint
 content_info_save (CamelFolderSummary *s, FILE *out,
 		   CamelMessageContentInfo *info)
 {
@@ -446,7 +445,7 @@ content_info_save (CamelFolderSummary *s, FILE *out,
 }
 
 void
-camel_imap_summary_add_offline (CamelFolderSummary *summary, const char *uid,
+camel_imap_summary_add_offline (CamelFolderSummary *summary, const gchar *uid,
 				CamelMimeMessage *message,
 				const CamelMessageInfo *info)
 {
@@ -478,7 +477,7 @@ camel_imap_summary_add_offline (CamelFolderSummary *summary, const char *uid,
 }
 
 void
-camel_imap_summary_add_offline_uncached (CamelFolderSummary *summary, const char *uid,
+camel_imap_summary_add_offline_uncached (CamelFolderSummary *summary, const gchar *uid,
 					 const CamelMessageInfo *info)
 {
 	CamelImapMessageInfo *mi;
