@@ -19,7 +19,6 @@
  *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-
 #ifndef __CAMEL_IMAP_STORE_SUMMARY_H__
 #define __CAMEL_IMAP_STORE_SUMMARY_H__
 
@@ -42,22 +41,20 @@ enum {
 	CAMEL_IMAP4_STORE_INFO_LAST,
 };
 
-
 struct _CamelFolderInfo;
 
-
 struct _CamelIMAP4StoreInfo {
 	CamelStoreInfo info;
 };
 
 struct _CamelIMAP4StoreSummary {
 	CamelStoreSummary summary;
-	
+
 	struct _CamelIMAP4StoreSummaryPrivate *priv;
-	
+
 	/* header info */
 	guint32 version;
-	
+
 	CamelIMAP4NamespaceList *namespaces;
 	guint32 capa;
 };
@@ -66,7 +63,6 @@ struct _CamelIMAP4StoreSummaryClass {
 	CamelStoreSummaryClass summary_class;
 };
 
-
 CamelType camel_imap4_store_summary_get_type (void);
 
 CamelIMAP4StoreSummary *camel_imap4_store_summary_new (void);
@@ -79,7 +75,7 @@ void camel_imap4_store_summary_note_info (CamelIMAP4StoreSummary *s, struct _Cam
 
 void camel_imap4_store_summary_unnote_info (CamelIMAP4StoreSummary *s, struct _CamelFolderInfo *fi);
 
-struct _CamelFolderInfo *camel_imap4_store_summary_get_folder_info (CamelIMAP4StoreSummary *s, const char *top, guint32 flags);
+struct _CamelFolderInfo *camel_imap4_store_summary_get_folder_info (CamelIMAP4StoreSummary *s, const gchar *top, guint32 flags);
 
 G_END_DECLS
 
